from .utils import (
    get_fld,
    get_tld,
    get_tld_names,
    is_tld,
    parse_tld,
    Result,
    update_tld_names,
)

__title__ = 'tld'
__version__ = '0.11.10'
__author__ = 'Artur Barseghyan'
__copyright__ = '2013-2019 Artur Barseghyan'
__license__ = 'MPL-1.1 OR GPL-2.0-only OR LGPL-2.1-or-later'
__all__ = (
    'get_fld',
    'get_tld',
    'get_tld_names',
    'is_tld',
    'parse_tld',
    'Result',
    'update_tld_names',
)
